@@ -24,11 +24,11 @@
 #define ZBX_STR(str)	ZBX_STR2(str)
 
 #define APPLICATION_NAME	"Zabbix Agent"
-#define ZABBIX_REVDATE		"30 September 2016"
+#define ZABBIX_REVDATE		"7 December 2016"
 #define ZABBIX_VERSION_MAJOR	3
 #define ZABBIX_VERSION_MINOR	0
-#define ZABBIX_VERSION_PATCH	5
-#define ZABBIX_VERSION_REVISION	62889
+#define ZABBIX_VERSION_PATCH	6
+#define ZABBIX_VERSION_REVISION	64244
 #define ZABBIX_VERSION_RC	""
 #define ZABBIX_VERSION		ZBX_STR(ZABBIX_VERSION_MAJOR) "." ZBX_STR(ZABBIX_VERSION_MINOR) "." \
 				ZBX_STR(ZABBIX_VERSION_PATCH) ZABBIX_VERSION_RC
