@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2015 Zabbix SIA
+** Copyright (C) 2001-2016 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -37,7 +37,7 @@ static int	zbx_execute_script_on_agent(DC_HOST *host, const char *command, char
 	const char	*__function_name = "zbx_execute_script_on_agent";
 	int		ret;
 	AGENT_RESULT	agent_result;
-	char		*param, *port = NULL;
+	char		*param = NULL, *port = NULL;
 	DC_ITEM		item;
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __function_name);
@@ -53,7 +53,8 @@ static int	zbx_execute_script_on_agent(DC_HOST *host, const char *command, char
 	}
 
 	port = zbx_strdup(port, item.interface.port_orig);
-	substitute_simple_macros(NULL, NULL, NULL, NULL, &host->hostid, NULL, NULL, &port, MACRO_TYPE_COMMON, NULL, 0);
+	substitute_simple_macros(NULL, NULL, NULL, NULL, &host->hostid, NULL, NULL, NULL,
+			&port, MACRO_TYPE_COMMON, NULL, 0);
 
 	if (SUCCEED != (ret = is_ushort(port, &item.interface.port)))
 	{
@@ -61,14 +62,19 @@ static int	zbx_execute_script_on_agent(DC_HOST *host, const char *command, char
 		goto fail;
 	}
 
-	param = zbx_dyn_escape_string(command, "\"");
-	item.key = zbx_dsprintf(item.key, "system.run[\"%s\",\"%s\"]", param, NULL == result ? "nowait" : "wait");
+	param = zbx_strdup(param, command);
+	if (SUCCEED != (ret = quote_key_param(&param, 0)))
+	{
+		zbx_snprintf(error, max_error_len, "Invalid param [%s]", param);
+		goto fail;
+	}
+
+	item.key = zbx_dsprintf(item.key, "system.run[%s,%s]", param, NULL == result ? "nowait" : "wait");
 	item.value_type = ITEM_VALUE_TYPE_TEXT;
-	zbx_free(param);
 
 	init_result(&agent_result);
 
-	alarm(CONFIG_TIMEOUT);
+	zbx_alarm_on(CONFIG_TIMEOUT);
 
 	if (SUCCEED != (ret = get_value_agent(&item, &agent_result)))
 	{
@@ -79,13 +85,14 @@ static int	zbx_execute_script_on_agent(DC_HOST *host, const char *command, char
 	else if (NULL != result && ISSET_TEXT(&agent_result))
 		*result = zbx_strdup(*result, agent_result.text);
 
-	alarm(0);
+	zbx_alarm_off();
 
 	free_result(&agent_result);
 
 	zbx_free(item.key);
 fail:
 	zbx_free(port);
+	zbx_free(param);
 
 	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", __function_name, zbx_result_string(ret));
 
@@ -113,7 +120,8 @@ static int	zbx_execute_ipmi_command(DC_HOST *host, const char *command, char *er
 	}
 
 	port = zbx_strdup(port, item.interface.port_orig);
-	substitute_simple_macros(NULL, NULL, NULL, NULL, &host->hostid, NULL, NULL, &port, MACRO_TYPE_COMMON, NULL, 0);
+	substitute_simple_macros(NULL, NULL, NULL, NULL, &host->hostid, NULL, NULL, NULL, &port,
+			MACRO_TYPE_COMMON, NULL, 0);
 
 	if (SUCCEED != (ret = is_ushort(port, &item.interface.port)))
 	{
@@ -139,10 +147,10 @@ static int	zbx_execute_script_on_terminal(DC_HOST *host, zbx_script_t *script, c
 		char *error, size_t max_error_len)
 {
 	const char	*__function_name = "zbx_execute_script_on_terminal";
-	int		ret;
+	int		ret = FAIL, i;
 	AGENT_RESULT	agent_result;
 	DC_ITEM		item;
-	int             (*function)();
+	int             (*function)(DC_ITEM *, AGENT_RESULT *);
 
 #ifdef HAVE_SSH2
 	assert(ZBX_SCRIPT_TYPE_SSH == script->type || ZBX_SCRIPT_TYPE_TELNET == script->type);
@@ -156,9 +164,18 @@ static int	zbx_execute_script_on_terminal(DC_HOST *host, zbx_script_t *script, c
 	memset(&item, 0, sizeof(item));
 	memcpy(&item.host, host, sizeof(item.host));
 
-	if (SUCCEED != (ret = DCconfig_get_interface_by_type(&item.interface, host->hostid, INTERFACE_TYPE_AGENT)))
+	for (i = 0; INTERFACE_TYPE_COUNT > i; i++)
 	{
-		zbx_snprintf(error, max_error_len, "Zabbix agent interface is not defined for host [%s]", host->host);
+		if (SUCCEED == (ret = DCconfig_get_interface_by_type(&item.interface, host->hostid,
+				INTERFACE_TYPE_PRIORITY[i])))
+		{
+			break;
+		}
+	}
+
+	if (FAIL == ret)
+	{
+		zbx_snprintf(error, max_error_len, "No interface defined for host [%s]", host->host);
 		goto fail;
 	}
 
@@ -175,7 +192,7 @@ static int	zbx_execute_script_on_terminal(DC_HOST *host, zbx_script_t *script, c
 			break;
 	}
 
-	substitute_simple_macros(NULL, NULL, NULL, NULL, &host->hostid, NULL, NULL,
+	substitute_simple_macros(NULL, NULL, NULL, NULL, &host->hostid, NULL, NULL, NULL,
 			&script->port, MACRO_TYPE_COMMON, NULL, 0);
 
 	if ('\0' != *script->port && SUCCEED != (ret = is_ushort(script->port, NULL)))
@@ -203,7 +220,7 @@ static int	zbx_execute_script_on_terminal(DC_HOST *host, zbx_script_t *script, c
 
 	init_result(&agent_result);
 
-	alarm(CONFIG_TIMEOUT);
+	zbx_alarm_on(CONFIG_TIMEOUT);
 
 	if (SUCCEED != (ret = function(&item, &agent_result)))
 	{
@@ -214,7 +231,7 @@ static int	zbx_execute_script_on_terminal(DC_HOST *host, zbx_script_t *script, c
 	else if (NULL != result && ISSET_TEXT(&agent_result))
 		*result = zbx_strdup(*result, agent_result.text);
 
-	alarm(0);
+	zbx_alarm_off();
 
 	free_result(&agent_result);
 
@@ -359,9 +376,9 @@ int	zbx_execute_script(DC_HOST *host, zbx_script_t *script, char **result, char
 			break;
 		case ZBX_SCRIPT_TYPE_SSH:
 #ifdef HAVE_SSH2
-			substitute_simple_macros(NULL, NULL, NULL, NULL, &host->hostid, NULL, NULL,
+			substitute_simple_macros(NULL, NULL, NULL, NULL, &host->hostid, NULL, NULL, NULL,
 					&script->publickey, MACRO_TYPE_COMMON, NULL, 0);
-			substitute_simple_macros(NULL, NULL, NULL, NULL, &host->hostid, NULL, NULL,
+			substitute_simple_macros(NULL, NULL, NULL, NULL, &host->hostid, NULL, NULL, NULL,
 					&script->privatekey, MACRO_TYPE_COMMON, NULL, 0);
 			/* break; is not missing here */
 #else
@@ -369,9 +386,9 @@ int	zbx_execute_script(DC_HOST *host, zbx_script_t *script, char **result, char
 			break;
 #endif
 		case ZBX_SCRIPT_TYPE_TELNET:
-			substitute_simple_macros(NULL, NULL, NULL, NULL, &host->hostid, NULL, NULL,
+			substitute_simple_macros(NULL, NULL, NULL, NULL, &host->hostid, NULL, NULL, NULL,
 					&script->username, MACRO_TYPE_COMMON, NULL, 0);
-			substitute_simple_macros(NULL, NULL, NULL, NULL, &host->hostid, NULL, NULL,
+			substitute_simple_macros(NULL, NULL, NULL, NULL, &host->hostid, NULL, NULL, NULL,
 					&script->password, MACRO_TYPE_COMMON, NULL, 0);
 
 			ret = zbx_execute_script_on_terminal(host, script, result, error, max_error_len);
@@ -386,7 +403,7 @@ int	zbx_execute_script(DC_HOST *host, zbx_script_t *script, char **result, char
 
 			if (SUCCEED == check_script_permissions(groupid, host->hostid, error, max_error_len))
 			{
-				substitute_simple_macros(NULL, NULL, NULL, NULL, NULL, host, NULL,
+				substitute_simple_macros(NULL, NULL, NULL, NULL, NULL, host, NULL, NULL,
 						&script->command, MACRO_TYPE_SCRIPT, NULL, 0);
 
 				ret = zbx_execute_script(host, script, result, error, max_error_len);	/* recursion */
